@@ -137,26 +137,33 @@ func TestFilter(t *testing.T) {
 
 	require.Len(t, artifacts.Filter(ByGoos("linux")).items, 1)
 	require.Len(t, artifacts.Filter(ByGoos("darwin")).items, 3)
+	require.Len(t, artifacts.Filter(ByGooses("linux", "darwin")).items, 4)
 
 	require.Len(t, artifacts.Filter(ByGoarch("amd64")).items, 5)
 	require.Empty(t, artifacts.Filter(ByGoarch("386")).items)
+	require.Len(t, artifacts.Filter(ByGoarches("arm64", "amd64")).items, 6)
 
 	require.Len(t, artifacts.Filter(And(ByGoarch("amd64"), ByGoamd64("v1"))).items, 2)
+	require.Len(t, artifacts.Filter(ByGoamd64s("v2", "v3")).items, 2)
 	require.Len(t, artifacts.Filter(ByGoamd64("v2")).items, 1)
 	require.Len(t, artifacts.Filter(ByGoamd64("v3")).items, 1)
 	require.Len(t, artifacts.Filter(ByGoamd64("v4")).items, 1)
 
 	require.Len(t, artifacts.Filter(And(ByGoarch("arm"), ByGoarm("6"))).items, 3)
 	require.Empty(t, artifacts.Filter(ByGoarm("7")).items)
+	require.Len(t, artifacts.Filter(ByGoarms("6", "7")).items, 3)
 
 	require.Len(t, artifacts.Filter(ByType(Checksum)).items, 2)
 	require.Empty(t, artifacts.Filter(ByType(Binary)).items)
+	require.Len(t, artifacts.Filter(ByTypes(Binary, Checksum)).items, 2)
 
 	require.Len(t, artifacts.Filter(OnlyReplacingUnibins).items, 12)
 	require.Len(t, artifacts.Filter(And(OnlyReplacingUnibins, ByGoos("darwin"))).items, 2)
 	require.Len(t, artifacts.Filter(And(Not(ByGoos("linux")), ByGoarch("arm64"))).items, 1)
 
 	require.Len(t, artifacts.Filter(nil).items, 13)
+	require.Len(t, artifacts.Filter(Or(nil)).items, 13)
+	require.Len(t, artifacts.Filter(And(nil)).items, 13)
 
 	require.Len(t, artifacts.Filter(
 		And(
@@ -587,9 +594,11 @@ func TestByIDs(t *testing.T) {
 		artifacts.Add(a)
 	}
 
-	require.Len(t, artifacts.Filter(ByIDs("check")).items, 2)
+	require.Len(t, artifacts.Filter(ByID("check")).items, 2)
+	require.Len(t, artifacts.Filter(ByID("foo")).items, 3)
 	require.Len(t, artifacts.Filter(ByIDs("foo")).items, 3)
 	require.Len(t, artifacts.Filter(ByIDs("foo", "bar")).items, 4)
+	require.Len(t, artifacts.Filter(ByIDs()).items, 5)
 }
 
 func TestByExts(t *testing.T) {
@@ -624,7 +633,9 @@ func TestByExts(t *testing.T) {
 
 	require.Len(t, artifacts.Filter(ByExt("deb")).items, 2)
 	require.Len(t, artifacts.Filter(ByExt("rpm")).items, 1)
-	require.Len(t, artifacts.Filter(ByExt("rpm", ".deb")).items, 3)
+	require.Len(t, artifacts.Filter(ByExts("rpm")).items, 1)
+	require.Len(t, artifacts.Filter(ByExts("rpm", ".deb")).items, 3)
+	require.Len(t, artifacts.Filter(ByExts()).items, 4)
 	require.Empty(t, artifacts.Filter(ByExt("foo")).items)
 }
 
