@@ -13,7 +13,7 @@ import (
 	"text/template"
 	"time"
 
-	"github.com/google/go-github/v78/github"
+	"github.com/google/go-github/v80/github"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/testctx"
 	"github.com/goreleaser/goreleaser/v2/internal/testlib"
@@ -39,6 +39,21 @@ func TestNewGitHubClient(t *testing.T) {
 		require.Equal(t, githubURL+"/api/uploads/", client.client.UploadURL.String())
 	})
 
+	t.Run("good urls ending with /", func(t *testing.T) {
+		githubURL := "https://github.mycompany.com"
+		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
+			GitHubURLs: config.GitHubURLs{
+				API:    githubURL + "/api/v3/",
+				Upload: githubURL + "/api/uploads/",
+			},
+		})
+
+		client, err := newGitHub(ctx, ctx.Token)
+		require.NoError(t, err)
+		require.Equal(t, githubURL+"/api/v3/", client.client.BaseURL.String())
+		require.Equal(t, githubURL+"/api/uploads/", client.client.UploadURL.String())
+	})
+
 	t.Run("bad api url", func(t *testing.T) {
 		ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 			GitHubURLs: config.GitHubURLs{
@@ -223,7 +238,7 @@ func TestGitHubGetDefaultBranch(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 
@@ -253,7 +268,7 @@ func TestGitHubGetDefaultBranchErr(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -291,7 +306,7 @@ func TestGitHubChangelog(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -338,7 +353,7 @@ func TestGitHubReleaseNotes(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -371,7 +386,7 @@ func TestGitHubReleaseNotesError(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -389,7 +404,6 @@ func TestGitHubReleaseNotesError(t *testing.T) {
 func TestGitHubCloseMilestone(t *testing.T) {
 	srv := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		defer r.Body.Close()
-		t.Log(r.URL.Path)
 
 		if r.URL.Path == "/api/v3/repos/someone/something/milestones" {
 			r, err := os.Open("testdata/github/milestones.json")
@@ -411,7 +425,7 @@ func TestGitHubCloseMilestone(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -469,7 +483,7 @@ func TestGitHubOpenPullRequestCrossRepo(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -523,7 +537,7 @@ func TestGitHubOpenPullRequestHappyPath(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -582,7 +596,7 @@ func TestGitHubOpenPullRequestNoBaseBranchDraft(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -629,7 +643,7 @@ func TestGitHubOpenPullRequestPRExists(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -680,7 +694,7 @@ func TestGitHubOpenPullRequestBaseEmpty(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -731,7 +745,7 @@ func TestGitHubOpenPullRequestHeadEmpty(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -761,6 +775,9 @@ func TestGitHubCreateFileHappyPathCreate(t *testing.T) {
 		}
 
 		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+			var data github.RepositoryContentFileOptions
+			assert.NoError(t, json.NewDecoder(r.Body).Decode(&data))
+			assert.Nil(t, data.SHA)
 			w.WriteHeader(http.StatusOK)
 			return
 		}
@@ -777,7 +794,7 @@ func TestGitHubCreateFileHappyPathCreate(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -807,6 +824,9 @@ func TestGitHubCreateFileHappyPathUpdate(t *testing.T) {
 		}
 
 		if r.URL.Path == "/api/v3/repos/someone/something/contents/file.txt" && r.Method == http.MethodPut {
+			var data github.RepositoryContentFileOptions
+			assert.NoError(t, json.NewDecoder(r.Body).Decode(&data))
+			assert.Equal(t, "fake", data.GetSHA())
 			w.WriteHeader(http.StatusOK)
 			return
 		}
@@ -823,7 +843,7 @@ func TestGitHubCreateFileHappyPathUpdate(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -884,7 +904,7 @@ func TestGitHubCreateFileFeatureBranchAlreadyExists(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -945,7 +965,7 @@ func TestGitHubCreateFileFeatureBranchDoesNotExist(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -992,7 +1012,7 @@ func TestGitHubCreateFileFeatureBranchNilObject(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -1035,7 +1055,7 @@ func TestGitHubCheckRateLimit(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -1076,7 +1096,7 @@ func TestGitHubCreateRelease(t *testing.T) {
 	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
-				API: srv.URL + "/",
+				API: srv.URL,
 			},
 			Release: config.Release{
 				NameTemplate: "v1.0.0",
@@ -1144,7 +1164,7 @@ func TestGitHubCreateReleaseDeleteExistingDraft(t *testing.T) {
 	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
-				API: srv.URL + "/",
+				API: srv.URL,
 			},
 			Release: config.Release{
 				NameTemplate: "v1.0.0",
@@ -1202,7 +1222,7 @@ func TestGitHubCreateReleaseUpdateExisting(t *testing.T) {
 	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
-				API: srv.URL + "/",
+				API: srv.URL,
 			},
 			Release: config.Release{
 				NameTemplate: "v1.0.0",
@@ -1263,7 +1283,7 @@ func TestGitHubCreateReleaseUseExistingDraft(t *testing.T) {
 	ctx := testctx.WrapWithCfg(t.Context(),
 		config.Project{
 			GitHubURLs: config.GitHubURLs{
-				API: srv.URL + "/",
+				API: srv.URL,
 			},
 			Release: config.Release{
 				NameTemplate: "v1.0.0",
@@ -1330,7 +1350,7 @@ func TestGitHubCreateFileWithGitHubAppToken(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
@@ -1392,7 +1412,7 @@ func TestGitHubCreateFileWithoutGitHubAppToken(t *testing.T) {
 
 	ctx := testctx.WrapWithCfg(t.Context(), config.Project{
 		GitHubURLs: config.GitHubURLs{
-			API: srv.URL + "/",
+			API: srv.URL,
 		},
 	})
 	client, err := newGitHub(ctx, "test-token")
