@@ -5,6 +5,7 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
 	"github.com/stretchr/testify/require"
 )
 
@@ -26,14 +27,15 @@ func TestCopySymlink(t *testing.T) {
 
 	fi, err := os.Lstat(c)
 	require.NoError(t, err)
-	require.True(t, fi.Mode()&os.ModeSymlink != 0)
+	require.NotEqual(t, 0, fi.Mode()&os.ModeSymlink)
 
 	l, err := os.Readlink(c)
 	require.NoError(t, err)
-	require.Equal(t, a, l)
+	require.Equal(t, a, filepath.ToSlash(l))
 }
 
 func TestEqualFilesModeChanged(t *testing.T) {
+	testlib.SkipIfWindows(t)
 	tmp := t.TempDir()
 	a := "testdata/somefile.txt"
 	b := tmp + "/somefile.txt"
