@@ -16,8 +16,11 @@ import (
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/chocolatey"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/custompublishers"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/docker"
+	dockerv2 "github.com/goreleaser/goreleaser/v2/internal/pipe/docker/v2"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/dockerdigest"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/ko"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/krew"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/mcp"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/milestone"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/nix"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/release"
@@ -47,6 +50,8 @@ func New() Pipe {
 			artifactory.Pipe{},
 			docker.Pipe{},
 			docker.ManifestPipe{},
+			dockerv2.Publish{},
+			dockerdigest.Pipe{},
 			ko.Pipe{},
 			sign.DockerPipe{},
 			snapcraft.Pipe{},
@@ -62,6 +67,7 @@ func New() Pipe {
 			krew.Pipe{},
 			scoop.Pipe{},
 			chocolatey.Pipe{},
+			mcp.New(),
 			milestone.Pipe{},
 			custompublishers.Pipe{},
 		},
