@@ -230,12 +230,12 @@ func TestRunPipeMetadata(t *testing.T) {
 						Completer:    "", // Separately tested in TestCompleter
 						Daemon:       "simple",
 						Desktop:      "foo_desktop",
-						Environment: map[string]interface{}{
+						Environment: map[string]any{
 							"foo": "bar",
 						},
 						Extensions:  []string{"foo_extension"},
 						InstallMode: "disable",
-						Passthrough: map[string]interface{}{
+						Passthrough: map[string]any{
 							"planet": "saturn",
 						},
 						Plugs:            []string{"home", "network", "network-bind", "personal-files"},
@@ -245,8 +245,8 @@ func TestRunPipeMetadata(t *testing.T) {
 						RestartCondition: "always",
 						RestartDelay:     "42ms",
 						Slots:            []string{"foo_slot"},
-						Sockets: map[string]interface{}{
-							"sock": map[string]interface{}{
+						Sockets: map[string]any{
+							"sock": map[string]any{
 								"listen-stream": "$SNAP_COMMON/socket",
 								"socket-group":  "socket-group",
 								"socket-mode":   0o640,
@@ -260,8 +260,8 @@ func TestRunPipeMetadata(t *testing.T) {
 						WatchdogTimeout: "45ms",
 					},
 				},
-				Plugs: map[string]interface{}{
-					"personal-files": map[string]interface{}{
+				Plugs: map[string]any{
+					"personal-files": map[string]any{
 						"read": []string{"$HOME/test"},
 					},
 				},
@@ -299,12 +299,12 @@ func TestRunPipeMetadata(t *testing.T) {
 			Completer:    "",
 			Daemon:       "simple",
 			Desktop:      "foo_desktop",
-			Environment: map[string]interface{}{
+			Environment: map[string]any{
 				"foo": "bar",
 			},
 			Extensions:  []string{"foo_extension"},
 			InstallMode: "disable",
-			Passthrough: map[string]interface{}{
+			Passthrough: map[string]any{
 				"planet": "saturn",
 			},
 			Plugs:            []string{"home", "network", "network-bind", "personal-files"},
@@ -314,8 +314,8 @@ func TestRunPipeMetadata(t *testing.T) {
 			RestartCondition: "always",
 			RestartDelay:     "42ms",
 			Slots:            []string{"foo_slot"},
-			Sockets: map[string]interface{}{
-				"sock": map[string]interface{}{
+			Sockets: map[string]any{
+				"sock": map[string]any{
 					"listen-stream": "$SNAP_COMMON/socket",
 					"socket-group":  "socket-group",
 					"socket-mode":   0o640,
@@ -329,7 +329,7 @@ func TestRunPipeMetadata(t *testing.T) {
 			WatchdogTimeout: "45ms",
 		},
 	}, metadata.Apps)
-	require.Equal(t, map[string]interface{}{"read": []interface{}{"$HOME/test"}}, metadata.Plugs["personal-files"])
+	require.Equal(t, map[string]any{"read": []any{"$HOME/test"}}, metadata.Plugs["personal-files"])
 	require.Equal(t, "$SNAP_DATA/etc", metadata.Layout["/etc/testprojectname"].Bind)
 }
 
@@ -498,6 +498,7 @@ func TestDefault(t *testing.T) {
 		Snapcrafts: []config.Snapcraft{{
 			Description: "hi",
 			Summary:     "hi",
+			Builds:      []string{"a"},
 		}},
 	})
 	require.NoError(t, Pipe{}.Default(ctx))
@@ -505,6 +506,8 @@ func TestDefault(t *testing.T) {
 	require.Equal(t, []string{"edge", "beta", "candidate", "stable"}, ctx.Config.Snapcrafts[0].ChannelTemplates)
 	require.Equal(t, "stable", ctx.Config.Snapcrafts[0].Grade)
 	require.Equal(t, "strict", ctx.Config.Snapcrafts[0].Confinement)
+	require.Equal(t, []string{"a"}, ctx.Config.Snapcrafts[0].IDs)
+	require.True(t, ctx.Deprecated)
 }
 
 func TestDefaultNoDescription(t *testing.T) {
@@ -560,7 +563,7 @@ func TestPublish(t *testing.T) {
 		Goarch: "amd64",
 		Goos:   "linux",
 		Type:   artifact.PublishableSnapcraft,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			releasesExtra: []string{"stable", "candidate"},
 		},
 	})
@@ -650,7 +653,7 @@ func addBinaries(t *testing.T, ctx *context.Context, name, dist string) {
 					Goos:   goos,
 					Goarm:  "6",
 					Type:   artifact.Binary,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraID: name,
 					},
 				})
@@ -663,7 +666,7 @@ func addBinaries(t *testing.T, ctx *context.Context, name, dist string) {
 					Goos:    goos,
 					Goamd64: "v1",
 					Type:    artifact.Binary,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraID: name,
 					},
 				})
@@ -674,7 +677,7 @@ func addBinaries(t *testing.T, ctx *context.Context, name, dist string) {
 					Goarch: goarch,
 					Goos:   goos,
 					Type:   artifact.Binary,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraID: name,
 					},
 				})
