@@ -1,3 +1,4 @@
+// Package teams announces new releases to Microsoft Teams.
 package teams
 
 import (
@@ -20,8 +21,11 @@ const (
 
 type Pipe struct{}
 
-func (Pipe) String() string                 { return "teams" }
-func (Pipe) Skip(ctx *context.Context) bool { return !ctx.Config.Announce.Teams.Enabled }
+func (Pipe) String() string { return "teams" }
+func (Pipe) Skip(ctx *context.Context) (bool, error) {
+	enable, err := tmpl.New(ctx).Bool(ctx.Config.Announce.Teams.Enabled)
+	return !enable, err
+}
 
 type Config struct {
 	Webhook string `env:"TEAMS_WEBHOOK,notEmpty"`
@@ -46,17 +50,17 @@ func (p Pipe) Default(ctx *context.Context) error {
 func (p Pipe) Announce(ctx *context.Context) error {
 	title, err := tmpl.New(ctx).Apply(ctx.Config.Announce.Teams.TitleTemplate)
 	if err != nil {
-		return fmt.Errorf("teams: %w", err)
+		return fmt.Errorf("%s: %w", p, err)
 	}
 
 	msg, err := tmpl.New(ctx).Apply(ctx.Config.Announce.Teams.MessageTemplate)
 	if err != nil {
-		return fmt.Errorf("teams: %w", err)
+		return fmt.Errorf("%s: %w", p, err)
 	}
 
 	cfg, err := env.ParseAs[Config]()
 	if err != nil {
-		return fmt.Errorf("teams: %w", err)
+		return fmt.Errorf("%s: %w", p, err)
 	}
 
 	log.Infof("posting: '%s'", msg)
@@ -73,11 +77,11 @@ func (p Pipe) Announce(ctx *context.Context) error {
 	messageCardSection.ActivityImage = ctx.Config.Announce.Teams.IconURL
 	err = msgCard.AddSection(messageCardSection)
 	if err != nil {
-		return fmt.Errorf("teams: %w", err)
+		return fmt.Errorf("%s: %w", p, err)
 	}
 	err = client.Send(cfg.Webhook, msgCard)
 	if err != nil {
-		return fmt.Errorf("teams: %w", err)
+		return fmt.Errorf("%s: %w", p, err)
 	}
 	return nil
 }
